# Doppyler - Python client for Sandman Doppler clocks

This module allows users to interact with their Sandman Doppler clocks, either locally or via the cloud control server. It is recommended that users interact with their clocks locally so that the cloud servers do not get abused.

To learn more about Sandman Clocks, check out https://www.sandmanclocks.com/
 